#!/usr/bin/env python
# -*- coding: utf-8 -*-

# import modules required for your project
# os and Texternet is suggested to always be imported

import os
from Texternet import Texternet

cwd = os.getcwd()

# The only 2 parameters given to an app is the message
# and the path of your app. Use os.chdir(path) to change
# your current working directory to your app directory. 

"""
        This is the file that Texternet looks for in your 
        app directory in order to run your app. You can 
        include more methods if you need, but this
         is the basic setup of an app.
"""

def main(x, path):

    """
            This is the method Texternet looks for that runs your app.
    """

    # The following is suggested to set up 
    # your app. However, your app may not require 
    # some of the features set up here like the
    # current working directory

    os.chdir(path)
    global cwd 
    cwd = os.getcwd()
    TN = Texternet('TWILIO_SID', 'TWILIO_TOKEN', "TWILIO_PHONE#")

    # A welcoming method/set up is also suggested
    # to set up the file system, if one is needed, 
    # of your app if a new user is using your app.

    if not x.from_ in os.listdir("./Users"):
        # x.from_ is the phone # of the user
        Welcoming(x.from_)

    # The rest of your app should be your processing
    # and sending of your result

    sampletext = "This is where your processing would happen"

    TN.sendMessage(x.from_, sampletext)

    # Please print the phone number and the message 
    # body for our system. The record isn't saved, 
    # it's just printed to the output to track errors.

    print(x.from_ + " " + x.body)

def Welcoming(Name):

    """
            This is a sample Welcoming method that takes in the name 
            of the folder you want to make for a new user. The way
            that is suggested to name folders is by phone number.
    """
    
    cwd = os.getcwd()
    os.chdir('Users/')
    os.makedirs(Name)

    # You could also do things such as make files for 
    # users or send them a welcome message if you want

    os.chdir(cwd)

"""
    You can include more methods if you need, but this is the basic setup of an app.
"""


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from collections import OrderedDict
from datetime import datetime

from twilio.rest import Client

name = 'Texternet'

"""This is the class that manages communication between the Texternet server and the Twilio API."""
class Texternet:
    pass
    def __init__(self, ACCOUNT_SID, AUTH_TOKEN, PHONENUM):
        """
                This method sets up a new connection to the Twilio API.

                """
        self.account_sid = ACCOUNT_SID
        self.auth_token = AUTH_TOKEN
        self.Login = False
        self.username = None
        self.userInfo = None
        self.client = Client(self.account_sid, self.auth_token)
        self.phone_num = PHONENUM

    def getMessages(self, date):
        """
                Using a given time, you get the messages from that point on.
                
                Parameters
                ----------
                date : datetime.datetime
                    The date of the starting point.
                    
                """
        messages = self.client.messages.list(
            date_sent_after=date,
            to=self.phone_num,
        )
        return messages

    def sendMessage(self, number, msg):
        """
                Sends a given text message to a given number.
                
                Parameters
                ----------
                number : str
                    given phone number preceded by the counry code. (ex. '+18171111111')

                msg : str
                    The message to be sent to the specified number.

                """
        message = self.client.messages.create(body=msg, from_=self.phone_num, to=number)
        return message.sid

    def sendFile(self, number, file):
        """
                Sends a given file to a given number.
                
                Parameters
                ----------
                number : str
                    given phone number preceded by the counry code. (ex. '+18171111111')

                file : str
                    The URL of the file to be sent to the specified number.

                """
        message = self.client.messages.create(
            from_=self.phone_num,
            media_url=file,
            to=number,
        )
        return message.sid


if __name__ == "__main__":
    print("can't run this file.")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="texternet",
    version="1.0.2",
    author="Kyle Henry",
    author_email="kylehenry@texternet.com",
    description="Package for interacting with and developing apps for Texternet.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/SonicHedghog/Texternet",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=['twilio'],
)